extern void select_prepare(void);
extern void compare_prepare(void);
extern void cx_compare(void);
extern void cx_compare_0(void);
extern void cx_compare_1(void);
extern void cx_compare_2(void);
extern void cx_compare_3(void);
extern void cx_compare_4(void);
extern void cx_select_toggle(void);
extern void cx_select_invert(void);
extern void cx_select_files(void);
extern void cx_select_allfiles(void);
extern void cx_select_nofiles(void);
